@@ -12,7 +12,7 @@ use pypi_types::{DistInfoMetadata, HashDigest, Yanked};
 /// Error converting [`pypi_types::File`] to [`distribution_type::File`].
 #[derive(Debug, Error)]
 pub enum FileConversionError {
-    #[error("Failed to parse 'requires-python': {0}")]
+    #[error("Failed to parse 'requires-python': `{0}`")]
     RequiresPython(String, #[source] VersionSpecifiersParseError),
     #[error("Failed to parse URL: {0}")]
     Url(String, #[source] url::ParseError),
