@@ -13,7 +13,8 @@ use crate::{Cursor, Pep508Error, Pep508ErrorSource};
 use pep440_rs::{Version, VersionPattern, VersionSpecifier};
 #[cfg(feature = "pyo3")]
 use pyo3::{
-    basic::CompareOp, exceptions::PyValueError, pyclass, pymethods, PyAny, PyResult, Python,
+    basic::CompareOp, exceptions::PyValueError, pyclass, pymethods, types::PyAnyMethods, PyResult,
+    Python,
 };
 #[cfg(feature = "serde")]
 use serde::{de, Deserialize, Deserializer, Serialize, Serializer};
@@ -377,7 +378,7 @@ pub struct MarkerEnvironment {
 
 impl MarkerEnvironment {
     /// Returns of the PEP 440 version typed value of the key in the current environment
-    fn get_version(&self, key: &MarkerValueVersion) -> &Version {
+    pub fn get_version(&self, key: &MarkerValueVersion) -> &Version {
         match key {
             MarkerValueVersion::ImplementationVersion => &self.implementation_version.version,
             MarkerValueVersion::PythonFullVersion => &self.python_full_version.version,
@@ -386,7 +387,7 @@ impl MarkerEnvironment {
     }
 
     /// Returns of the stringly typed value of the key in the current environment
-    fn get_string(&self, key: &MarkerValueString) -> &str {
+    pub fn get_string(&self, key: &MarkerValueString) -> &str {
         match key {
             MarkerValueString::ImplementationName => &self.implementation_name,
             MarkerValueString::OsName | MarkerValueString::OsNameDeprecated => &self.os_name,
@@ -476,9 +477,9 @@ impl MarkerEnvironment {
     /// Query the current python interpreter to get the correct marker value
     #[staticmethod]
     fn current(py: Python<'_>) -> PyResult<Self> {
-        let os = py.import("os")?;
-        let platform = py.import("platform")?;
-        let sys = py.import("sys")?;
+        let os = py.import_bound("os")?;
+        let platform = py.import_bound("platform")?;
+        let sys = py.import_bound("sys")?;
         let python_version_tuple: (String, String, String) = platform
             .getattr("python_version_tuple")?
             .call0()?
@@ -487,7 +488,7 @@ impl MarkerEnvironment {
         // See pseudocode at
         // https://packaging.python.org/en/latest/specifications/dependency-specifiers/#environment-markers
         let name = sys.getattr("implementation")?.getattr("name")?.extract()?;
-        let info: &PyAny = sys.getattr("implementation")?.getattr("version")?;
+        let info = sys.getattr("implementation")?.getattr("version")?;
         let kind = info.getattr("releaselevel")?.extract::<String>()?;
         let implementation_version: String = format!(
             "{}.{}.{}{}",
@@ -967,6 +968,88 @@ impl MarkerTree {
         }
     }
 
+    /// Remove the extras from a marker, returning `None` if the marker tree evaluates to `true`.
+    ///
+    /// Any `extra` markers that are always `true` given the provided extras will be removed.
+    /// Any `extra` markers that are always `false` given the provided extras will be left
+    /// unchanged.
+    ///
+    /// For example, if `dev` is a provided extra, given `sys_platform == 'linux' and extra == 'dev'`,
+    /// the marker will be simplified to `sys_platform == 'linux'`.
+    pub fn simplify_extras(self, extras: &[ExtraName]) -> Option<MarkerTree> {
+        /// Returns `true` if the given expression is always `true` given the set of extras.
+        pub fn is_true(expression: &MarkerExpression, extras: &[ExtraName]) -> bool {
+            // Ex) `extra == 'dev'`
+            if expression.l_value == MarkerValue::Extra {
+                if let MarkerValue::QuotedString(r_string) = &expression.r_value {
+                    if let Ok(r_extra) = ExtraName::from_str(r_string) {
+                        return extras.contains(&r_extra);
+                    }
+                }
+            }
+            // Ex) `'dev' == extra`
+            if expression.r_value == MarkerValue::Extra {
+                if let MarkerValue::QuotedString(l_string) = &expression.l_value {
+                    if let Ok(l_extra) = ExtraName::from_str(l_string) {
+                        return extras.contains(&l_extra);
+                    }
+                }
+            }
+            false
+        }
+
+        match self {
+            Self::Expression(expression) => {
+                // If the expression is true, we can remove the marker entirely.
+                if is_true(&expression, extras) {
+                    None
+                } else {
+                    // If not, return the original marker.
+                    Some(Self::Expression(expression))
+                }
+            }
+            Self::And(expressions) => {
+                // Remove any expressions that are _true_ due to the presence of an extra.
+                let simplified = expressions
+                    .into_iter()
+                    .filter_map(|marker| marker.simplify_extras(extras))
+                    .collect::<Vec<_>>();
+
+                // If there are no expressions left, return None.
+                if simplified.is_empty() {
+                    None
+                } else if simplified.len() == 1 {
+                    // If there is only one expression left, return the remaining expression.
+                    simplified.into_iter().next()
+                } else {
+                    // If there are still expressions left, return the simplified marker.
+                    Some(Self::And(simplified))
+                }
+            }
+            Self::Or(expressions) => {
+                let num_expressions = expressions.len();
+
+                // Remove any expressions that are _true_ due to the presence of an extra.
+                let simplified = expressions
+                    .into_iter()
+                    .filter_map(|marker| marker.simplify_extras(extras))
+                    .collect::<Vec<_>>();
+
+                // If _any_ of the expressions are true (i.e., if any of the markers were filtered
+                // out in the above filter step), the entire marker is true.
+                if simplified.len() < num_expressions {
+                    None
+                } else if simplified.len() == 1 {
+                    // If there is only one expression left, return the remaining expression.
+                    simplified.into_iter().next()
+                } else {
+                    // If there are still expressions left, return the simplified marker.
+                    Some(Self::Or(simplified))
+                }
+            }
+        }
+    }
+
     /// Same as [`Self::evaluate`], but instead of using logging to warn, you can pass your own
     /// handler for warnings
     pub fn evaluate_reporter(
@@ -1368,9 +1451,13 @@ fn parse_markers(markers: &str) -> Result<MarkerTree, Pep508Error> {
 #[cfg(test)]
 mod test {
     use crate::marker::{MarkerEnvironment, StringVersion};
-    use crate::{MarkerExpression, MarkerOperator, MarkerTree, MarkerValue, MarkerValueString};
+    use crate::{
+        MarkerExpression, MarkerOperator, MarkerTree, MarkerValue, MarkerValueString,
+        MarkerValueVersion,
+    };
     use insta::assert_snapshot;
     use std::str::FromStr;
+    use uv_normalize::ExtraName;
 
     fn parse_err(input: &str) -> String {
         MarkerTree::from_str(input).unwrap_err().to_string()
@@ -1616,4 +1703,99 @@ mod test {
         )
         .unwrap();
     }
+
+    #[test]
+    fn test_simplify_extras() {
+        // Given `os_name == "nt" and extra == "dev"`, simplify to `os_name == "nt"`.
+        let markers = MarkerTree::from_str(r#"os_name == "nt" and extra == "dev""#).unwrap();
+        let simplified = markers.simplify_extras(&[ExtraName::from_str("dev").unwrap()]);
+        assert_eq!(
+            simplified,
+            Some(MarkerTree::Expression(MarkerExpression {
+                l_value: MarkerValue::MarkerEnvString(MarkerValueString::OsName),
+                operator: MarkerOperator::Equal,
+                r_value: MarkerValue::QuotedString("nt".to_string()),
+            }))
+        );
+
+        // Given `os_name == "nt" or extra == "dev"`, remove the marker entirely.
+        let markers = MarkerTree::from_str(r#"os_name == "nt" or extra == "dev""#).unwrap();
+        let simplified = markers.simplify_extras(&[ExtraName::from_str("dev").unwrap()]);
+        assert_eq!(simplified, None);
+
+        // Given `extra == "dev"`, remove the marker entirely.
+        let markers = MarkerTree::from_str(r#"extra == "dev""#).unwrap();
+        let simplified = markers.simplify_extras(&[ExtraName::from_str("dev").unwrap()]);
+        assert_eq!(simplified, None);
+
+        // Given `extra == "dev" and extra == "test"`, simplify to `extra == "test"`.
+        let markers = MarkerTree::from_str(r#"extra == "dev" and extra == "test""#).unwrap();
+        let simplified = markers.simplify_extras(&[ExtraName::from_str("dev").unwrap()]);
+        assert_eq!(
+            simplified,
+            Some(MarkerTree::Expression(MarkerExpression {
+                l_value: MarkerValue::Extra,
+                operator: MarkerOperator::Equal,
+                r_value: MarkerValue::QuotedString("test".to_string()),
+            }))
+        );
+
+        // Given `os_name == "nt" and extra == "test"`, don't simplify.
+        let markers = MarkerTree::from_str(r#"os_name == "nt" and extra == "test""#).unwrap();
+        let simplified = markers.simplify_extras(&[ExtraName::from_str("dev").unwrap()]);
+        assert_eq!(
+            simplified,
+            Some(MarkerTree::And(vec![
+                MarkerTree::Expression(MarkerExpression {
+                    l_value: MarkerValue::MarkerEnvString(MarkerValueString::OsName),
+                    operator: MarkerOperator::Equal,
+                    r_value: MarkerValue::QuotedString("nt".to_string()),
+                }),
+                MarkerTree::Expression(MarkerExpression {
+                    l_value: MarkerValue::Extra,
+                    operator: MarkerOperator::Equal,
+                    r_value: MarkerValue::QuotedString("test".to_string()),
+                }),
+            ]))
+        );
+
+        // Given `os_name == "nt" and (python_version == "3.7" or extra == "dev")`, simplify to
+        // `os_name == "nt".
+        let markers = MarkerTree::from_str(
+            r#"os_name == "nt" and (python_version == "3.7" or extra == "dev")"#,
+        )
+        .unwrap();
+        let simplified = markers.simplify_extras(&[ExtraName::from_str("dev").unwrap()]);
+        assert_eq!(
+            simplified,
+            Some(MarkerTree::Expression(MarkerExpression {
+                l_value: MarkerValue::MarkerEnvString(MarkerValueString::OsName),
+                operator: MarkerOperator::Equal,
+                r_value: MarkerValue::QuotedString("nt".to_string()),
+            }))
+        );
+
+        // Given `os_name == "nt" or (python_version == "3.7" and extra == "dev")`, simplify to
+        // `os_name == "nt" or python_version == "3.7"`.
+        let markers = MarkerTree::from_str(
+            r#"os_name == "nt" or (python_version == "3.7" and extra == "dev")"#,
+        )
+        .unwrap();
+        let simplified = markers.simplify_extras(&[ExtraName::from_str("dev").unwrap()]);
+        assert_eq!(
+            simplified,
+            Some(MarkerTree::Or(vec![
+                MarkerTree::Expression(MarkerExpression {
+                    l_value: MarkerValue::MarkerEnvString(MarkerValueString::OsName),
+                    operator: MarkerOperator::Equal,
+                    r_value: MarkerValue::QuotedString("nt".to_string()),
+                }),
+                MarkerTree::Expression(MarkerExpression {
+                    l_value: MarkerValue::MarkerEnvVersion(MarkerValueVersion::PythonVersion),
+                    operator: MarkerOperator::Equal,
+                    r_value: MarkerValue::QuotedString("3.7".to_string()),
+                }),
+            ]))
+        );
+    }
 }
