@@ -1,52 +1,72 @@
-use distribution_types::{git_reference, DirectUrlSourceDist, GitSourceDist, PathSourceDist};
+use distribution_types::{
+    git_reference, DirectUrlSourceDist, GitSourceDist, Hashed, PathSourceDist,
+};
 use platform_tags::Tags;
 use uv_cache::{ArchiveTimestamp, Cache, CacheBucket, CacheShard, WheelCache};
 use uv_fs::symlinks;
+use uv_types::HashStrategy;
 
 use crate::index::cached_wheel::CachedWheel;
-use crate::source::{read_http_revision, read_timestamped_revision, REVISION};
+use crate::source::{HttpRevisionPointer, LocalRevisionPointer, HTTP_REVISION, LOCAL_REVISION};
 use crate::Error;
 
 /// A local index of built distributions for a specific source distribution.
-pub struct BuiltWheelIndex;
+#[derive(Debug)]
+pub struct BuiltWheelIndex<'a> {
+    cache: &'a Cache,
+    tags: &'a Tags,
+    hasher: &'a HashStrategy,
+}
+
+impl<'a> BuiltWheelIndex<'a> {
+    /// Initialize an index of built distributions.
+    pub fn new(cache: &'a Cache, tags: &'a Tags, hasher: &'a HashStrategy) -> Self {
+        Self {
+            cache,
+            tags,
+            hasher,
+        }
+    }
 
-impl BuiltWheelIndex {
     /// Return the most compatible [`CachedWheel`] for a given source distribution at a direct URL.
     ///
     /// This method does not perform any freshness checks and assumes that the source distribution
     /// is already up-to-date.
-    pub fn url(
-        source_dist: &DirectUrlSourceDist,
-        cache: &Cache,
-        tags: &Tags,
-    ) -> Result<Option<CachedWheel>, Error> {
+    pub fn url(&self, source_dist: &DirectUrlSourceDist) -> Result<Option<CachedWheel>, Error> {
         // For direct URLs, cache directly under the hash of the URL itself.
-        let cache_shard = cache.shard(
+        let cache_shard = self.cache.shard(
             CacheBucket::BuiltWheels,
             WheelCache::Url(source_dist.url.raw()).root(),
         );
 
-        // Read the revision from the cache. There's no need to enforce freshness, since we
-        // enforce freshness on the entries.
-        let revision_entry = cache_shard.entry(REVISION);
-        let Some(revision) = read_http_revision(&revision_entry)? else {
+        // Read the revision from the cache.
+        let Some(pointer) = HttpRevisionPointer::read_from(cache_shard.entry(HTTP_REVISION))?
+        else {
             return Ok(None);
         };
 
-        Ok(Self::find(&cache_shard.shard(revision.id()), tags))
+        // Enforce hash-checking by omitting any wheels that don't satisfy the required hashes.
+        let revision = pointer.into_revision();
+        if !revision.satisfies(self.hasher.get(source_dist)) {
+            return Ok(None);
+        }
+
+        Ok(self.find(&cache_shard.shard(revision.id())))
     }
 
     /// Return the most compatible [`CachedWheel`] for a given source distribution at a local path.
-    pub fn path(
-        source_dist: &PathSourceDist,
-        cache: &Cache,
-        tags: &Tags,
-    ) -> Result<Option<CachedWheel>, Error> {
-        let cache_shard = cache.shard(
+    pub fn path(&self, source_dist: &PathSourceDist) -> Result<Option<CachedWheel>, Error> {
+        let cache_shard = self.cache.shard(
             CacheBucket::BuiltWheels,
             WheelCache::Path(&source_dist.url).root(),
         );
 
+        // Read the revision from the cache.
+        let Some(pointer) = LocalRevisionPointer::read_from(cache_shard.entry(LOCAL_REVISION))?
+        else {
+            return Ok(None);
+        };
+
         // Determine the last-modified time of the source distribution.
         let Some(modified) =
             ArchiveTimestamp::from_path(&source_dist.path).map_err(Error::CacheRead)?
@@ -54,28 +74,37 @@ impl BuiltWheelIndex {
             return Err(Error::DirWithoutEntrypoint);
         };
 
-        // Read the revision from the cache. There's no need to enforce freshness, since we
-        // enforce freshness on the entries.
-        let revision_entry = cache_shard.entry(REVISION);
-        let Some(revision) = read_timestamped_revision(&revision_entry, modified)? else {
+        // If the distribution is stale, omit it from the index.
+        if !pointer.is_up_to_date(modified) {
             return Ok(None);
-        };
+        }
 
-        Ok(Self::find(&cache_shard.shard(revision.id()), tags))
+        // Enforce hash-checking by omitting any wheels that don't satisfy the required hashes.
+        let revision = pointer.into_revision();
+        if !revision.satisfies(self.hasher.get(source_dist)) {
+            return Ok(None);
+        }
+
+        Ok(self.find(&cache_shard.shard(revision.id())))
     }
 
     /// Return the most compatible [`CachedWheel`] for a given source distribution at a git URL.
-    pub fn git(source_dist: &GitSourceDist, cache: &Cache, tags: &Tags) -> Option<CachedWheel> {
+    pub fn git(&self, source_dist: &GitSourceDist) -> Option<CachedWheel> {
+        // Enforce hash-checking, which isn't supported for Git distributions.
+        if self.hasher.get(source_dist).is_validate() {
+            return None;
+        }
+
         let Ok(Some(git_sha)) = git_reference(&source_dist.url) else {
             return None;
         };
 
-        let cache_shard = cache.shard(
+        let cache_shard = self.cache.shard(
             CacheBucket::BuiltWheels,
             WheelCache::Git(&source_dist.url, &git_sha.to_short_string()).root(),
         );
 
-        Self::find(&cache_shard, tags)
+        self.find(&cache_shard)
     }
 
     /// Find the "best" distribution in the index for a given source distribution.
@@ -94,16 +123,16 @@ impl BuiltWheelIndex {
     /// ```
     ///
     /// The `shard` should be `built-wheels-v0/pypi/django-allauth-0.51.0.tar.gz`.
-    fn find(shard: &CacheShard, tags: &Tags) -> Option<CachedWheel> {
+    fn find(&self, shard: &CacheShard) -> Option<CachedWheel> {
         let mut candidate: Option<CachedWheel> = None;
 
         // Unzipped wheels are stored as symlinks into the archive directory.
         for subdir in symlinks(shard) {
-            match CachedWheel::from_path(&subdir) {
+            match CachedWheel::from_built_source(&subdir) {
                 None => {}
                 Some(dist_info) => {
                     // Pick the wheel with the highest priority
-                    let compatibility = dist_info.filename.compatibility(tags);
+                    let compatibility = dist_info.filename.compatibility(self.tags);
 
                     // Only consider wheels that are compatible with our tags.
                     if !compatibility.is_compatible() {
@@ -113,7 +142,7 @@ impl BuiltWheelIndex {
                     if let Some(existing) = candidate.as_ref() {
                         // Override if the wheel is newer, or "more" compatible.
                         if dist_info.filename.version > existing.filename.version
-                            || compatibility > existing.filename.compatibility(tags)
+                            || compatibility > existing.filename.compatibility(self.tags)
                         {
                             candidate = Some(dist_info);
                         }
