@@ -14,22 +14,24 @@ use distribution_types::{IndexLocations, Resolution, SourceDist};
 use pep508_rs::{MarkerEnvironment, Requirement, StringVersion};
 use platform_tags::{Arch, Os, Platform, Tags};
 use uv_cache::Cache;
-use uv_client::{FlatIndex, RegistryClientBuilder};
+use uv_client::RegistryClientBuilder;
+use uv_configuration::{BuildKind, Constraints, NoBinary, NoBuild, Overrides, SetupPyStrategy};
 use uv_interpreter::{find_default_python, Interpreter, PythonEnvironment};
 use uv_resolver::{
-    DisplayResolutionGraph, Exclusions, InMemoryIndex, Manifest, Options, OptionsBuilder,
-    PreReleaseMode, Preference, ResolutionGraph, ResolutionMode, Resolver,
+    DisplayResolutionGraph, ExcludeNewer, Exclusions, FlatIndex, InMemoryIndex, Manifest, Options,
+    OptionsBuilder, PreReleaseMode, Preference, ResolutionGraph, ResolutionMode, Resolver,
 };
 use uv_types::{
-    BuildContext, BuildIsolation, BuildKind, Constraints, EmptyInstalledPackages, NoBinary,
-    NoBuild, Overrides, SetupPyStrategy, SourceBuildTrait,
+    BuildContext, BuildIsolation, EmptyInstalledPackages, HashStrategy, SourceBuildTrait,
 };
 
 // Exclude any packages uploaded after this date.
-static EXCLUDE_NEWER: Lazy<DateTime<Utc>> = Lazy::new(|| {
-    DateTime::parse_from_rfc3339("2023-11-18T12:00:00Z")
-        .unwrap()
-        .with_timezone(&Utc)
+static EXCLUDE_NEWER: Lazy<ExcludeNewer> = Lazy::new(|| {
+    ExcludeNewer::from(
+        DateTime::parse_from_rfc3339("2023-11-18T12:00:00Z")
+            .unwrap()
+            .with_timezone(&Utc),
+    )
 });
 
 struct DummyContext {
@@ -125,6 +127,7 @@ async fn resolve(
         find_default_python(&Cache::temp().unwrap()).expect("Expected a python to be installed");
     let interpreter = Interpreter::artificial(real_interpreter.platform().clone(), markers.clone());
     let build_context = DummyContext::new(Cache::temp()?, interpreter.clone());
+    let hashes = HashStrategy::None;
     let installed_packages = EmptyInstalledPackages;
     let resolver = Resolver::new(
         manifest,
@@ -135,6 +138,7 @@ async fn resolve(
         &client,
         &flat_index,
         &index,
+        &hashes,
         &build_context,
         &installed_packages,
     )?;
@@ -698,6 +702,7 @@ static TAGS_311: Lazy<Tags> = Lazy::new(|| {
         (3, 11),
         "cpython",
         (3, 11),
+        false,
     )
     .unwrap()
 });
@@ -730,6 +735,7 @@ static TAGS_310: Lazy<Tags> = Lazy::new(|| {
         (3, 10),
         "cpython",
         (3, 10),
+        false,
     )
     .unwrap()
 });
